// Generated by gmmproc 2.66.8 -- DO NOT MODIFY!


#include <glibmm.h>

#include <atkmm/implementor.h>
#include <atkmm/private/implementor_p.h>


// -*- c++ -*-
/* $Id: implementor.ccg,v 1.1 2004/04/11 21:00:53 murrayc Exp $ */

/* Copyright 1998-2002 The gtkmm Development Team
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <atkmm/object.h>
#include <atk/atkobject.h>


namespace
{
} // anonymous namespace


namespace Glib
{

Glib::RefPtr<Atk::Implementor> wrap(AtkImplementor* object, bool take_copy)
{
  return Glib::RefPtr<Atk::Implementor>( dynamic_cast<Atk::Implementor*> (Glib::wrap_auto_interface<Atk::Implementor> ((GObject*)(object), take_copy)) );
  //We use dynamic_cast<> in case of multiple inheritance.
}

} // namespace Glib


namespace Atk
{


/* The *_Class implementation: */

const Glib::Interface_Class& Implementor_Class::init()
{
  if(!gtype_) // create the GType if necessary
  {
    // Glib::Interface_Class has to know the interface init function
    // in order to add interfaces to implementing types.
    class_init_func_ = &Implementor_Class::iface_init_function;

    // We can not derive from another interface, and it is not necessary anyway.
    gtype_ = atk_implementor_get_type();
  }

  return *this;
}

void Implementor_Class::iface_init_function(void* g_iface, void*)
{
  const auto klass = static_cast<BaseClassType*>(g_iface);

  //This is just to avoid an "unused variable" warning when there are no vfuncs or signal handlers to connect.
  //This is a temporary fix until I find out why I can not seem to derive a GtkFileChooser interface. murrayc
  g_assert(klass != nullptr);

  klass->ref_accessible = &ref_accessible_vfunc_callback;

}

AtkObject* Implementor_Class::ref_accessible_vfunc_callback(AtkImplementor* self)
{
  const auto obj_base = static_cast<Glib::ObjectBase*>(
      Glib::ObjectBase::_get_current_wrapper((GObject*)self));

  // Non-gtkmmproc-generated custom classes implicitly call the default
  // Glib::ObjectBase constructor, which sets is_derived_. But gtkmmproc-
  // generated classes can use this optimisation, which avoids the unnecessary
  // parameter conversions if there is no possibility of the virtual function
  // being overridden:
  if(obj_base && obj_base->is_derived_())
  {
    const auto obj = dynamic_cast<CppObjectType* const>(obj_base);
    if(obj) // This can be NULL during destruction.
    {
      try // Trap C++ exceptions which would normally be lost because this is a C callback.
      {
        // Call the virtual member method, which derived classes might override.
        return Glib::unwrap(obj->ref_accessibile_vfunc());
      }
      catch(...)
      {
        Glib::exception_handlers_invoke();
      }
    }
  }

  BaseClassType *const base = static_cast<BaseClassType*>(
      g_type_interface_peek_parent( // Get the parent interface of the interface (The original underlying C interface).
g_type_interface_peek(G_OBJECT_GET_CLASS(self), CppObjectType::get_type()) // Get the interface.
)  );

  // Call the original underlying C function:
  if(base && base->ref_accessible)
    return (*base->ref_accessible)(self);

  using RType = AtkObject*;
  return RType();
}


Glib::ObjectBase* Implementor_Class::wrap_new(GObject* object)
{
  return new Implementor((AtkImplementor*)(object));
}


/* The implementation: */

Implementor::Implementor()
:
  Glib::Interface(implementor_class_.init())
{}

Implementor::Implementor(AtkImplementor* castitem)
:
  Glib::Interface((GObject*)(castitem))
{}

Implementor::Implementor(const Glib::Interface_Class& interface_class)
: Glib::Interface(interface_class)
{
}

Implementor::Implementor(Implementor&& src) noexcept
: Glib::Interface(std::move(src))
{}

Implementor& Implementor::operator=(Implementor&& src) noexcept
{
  Glib::Interface::operator=(std::move(src));
  return *this;
}

Implementor::~Implementor() noexcept
{}

// static
void Implementor::add_interface(GType gtype_implementer)
{
  implementor_class_.init().add_interface(gtype_implementer);
}

Implementor::CppClassType Implementor::implementor_class_; // initialize static member

GType Implementor::get_type()
{
  return implementor_class_.init().get_type();
}


GType Implementor::get_base_type()
{
  return atk_implementor_get_type();
}


Glib::RefPtr<Object> Atk::Implementor::ref_accessibile_vfunc() 
{
  const auto base = static_cast<BaseClassType*>(
      g_type_interface_peek_parent( // Get the parent interface of the interface (The original underlying C interface).
g_type_interface_peek(G_OBJECT_GET_CLASS(gobject_), CppObjectType::get_type()) // Get the interface.
)  );

  if(base && base->ref_accessible)
  {
    Glib::RefPtr<Object> retval(Glib::wrap((*base->ref_accessible)(gobj()), true));
    return retval;
  }

  using RType = Glib::RefPtr<Object>;
  return RType();
}


} // namespace Atk


